# uhb

[![PyPI Status][pypi-image]][pypi-url]
[![Build Status][travis-image]][travis-url]
[![Coverage Status][coveralls-image]][coveralls-url]

Upheaval Buckling (UHB) toolkit

![uhb](https://nonerieska.files.wordpress.com/2013/02/post12-2.jpg)

Includes:

-   Analytical calculation
-   Soil springs (ASCE, GSW and FS2000)
-   Natural wavelength and foundation profile (JIP)
-   Non-linear material model (Ramberg-Osgood, SR function)

## Installation

```sh
$ pip install uhb
```

<!-- Markdown link & img dfn's -->

[pypi-image]: https://img.shields.io/pypi/v/uhb.svg
[pypi-url]: https://pypi.python.org/pypi/uhb
[travis-image]: https://travis-ci.org/benranderson/uhb.svg?branch=master
[travis-url]: https://travis-ci.org/benranderson/uhb
[coveralls-image]: https://coveralls.io/repos/github/benranderson/uhb/badge.svg?branch=master
[coveralls-url]: https://coveralls.io/github/benranderson/uhb?branch=master
